@@ -1,14 +1,35 @@
 /*
- * Internationalization.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2008      Vreixo Formoso
- * Copyright (c) 2008-2009 Operational Dynamics Consulting Pty Ltd
- * 
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" plus the "Classpath Exception" (you may link to this code as a
- * library into other programs provided you don't make a derivation of it).
- * See the LICENCE file for the terms governing usage and redistribution.
+ * Copyright © 2008      Vreixo Formoso
+ * Copyright © 2008-2011 Operational Dynamics Consulting, Pty Ltd and Others
+ *
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
+ *
+ * Linking this library statically or dynamically with other modules is making
+ * a combined work based on this library. Thus, the terms and conditions of
+ * the GPL cover the whole combination. As a special exception (the
+ * "Claspath Exception"), the copyright holders of this library give you
+ * permission to link this library with independent modules to produce an
+ * executable, regardless of the license terms of these independent modules,
+ * and to copy and distribute the resulting executable under terms of your
+ * choice, provided that you also meet, for each linked independent module,
+ * the terms and conditions of the license of that module. An independent
+ * module is a module which is not derived from or based on this library. If
+ * you modify this library, you may extend the Classpath Exception to your
+ * version of the library, but you are not obligated to do so. If you do not
+ * wish to do so, delete this exception statement from your version.
  */
 package org.freedesktop.bindings;
 
@@ -25,8 +46,9 @@ import java.text.MessageFormat;
  * formatting as used in a given country are collectively referred to as a
  * <i>locale</i>.
  * <dt>Internationalization</dt>
- * <dd><i>Internationalization</i> is the process of preparing applications
- * to support multiple languages. You will frequently see this abbreviated as "<code>i18n</code>".</dd>
+ * <dd><i>Internationalization</i> is the process of preparing applications to
+ * support multiple languages. You will frequently see this abbreviated as "
+ * <code>i18n</code>".</dd>
  * <dt>Localization</dt>
  * <dd>Whereby other people convert your software into their own locale.
  * <i>Localization</i>, as this is process is referred to, involves more than
@@ -125,24 +147,24 @@ import java.text.MessageFormat;
  * </pre>
  * 
  * The added complexity comes from the need to cater for the "positional
- * parameters" (here <code>filename</code> and <code>date</code>) which
- * may have a different order when rendered in someone else's language. Again,
- * you don't need to know the specifics for every possible target locale, you
- * just need to supply the information in a form that can be localized.
+ * parameters" (here <code>filename</code> and <code>date</code>) which may
+ * have a different order when rendered in someone else's language. Again, you
+ * don't need to know the specifics for every possible target locale, you just
+ * need to supply the information in a form that can be localized.
  * 
  * <p>
  * To format these parameters, you use the {@link MessageFormat} syntax. Put
  * briefly, you will:
  * 
  * <ul>
- * <li>Refer to any parameter with a <code>{n}</code> in your message,
- * where <code>n</code> is the <code>0</code>-based index of the
- * parameter as you submitted to the <code>_()</code> function.</li>
+ * <li>Refer to any parameter with a <code>{n}</code> in your message, where
+ * <code>n</code> is the <code>0</code>-based index of the parameter as you
+ * submitted to the <code>_()</code> function.</li>
  * <li>If the parameter needs to be formatted (numbers, dates, currency, etc)
- * you pass a format type parameter ("<code>number</code>", "<code>date</code>", "<code>time</code>")
- * and optionally a format style qualifier (in the above example, "<code>long</code>",
- * indicating a longer form). See the MessageFormat documentation for further
- * details.</li>
+ * you pass a format type parameter ("<code>number</code>", "<code>date</code>
+ * ", "<code>time</code>") and optionally a format style qualifier (in the
+ * above example, "<code>long</code>", indicating a longer form). See the
+ * MessageFormat documentation for further details.</li>
  * </ul>
  * 
  * <p>
@@ -181,8 +203,8 @@ import java.text.MessageFormat;
  * <dt><code>fr</code>
  * <dd>French (generic)
  * </dl>
- * etc. You'll note the addition of qualifiers like <code>.UTF-8</code>
- * which are how a locale indicates support for specific character sets.
+ * etc. You'll note the addition of qualifiers like <code>.UTF-8</code> which
+ * are how a locale indicates support for specific character sets.
  * 
  * <p>
  * There is also one other locale you will see:
@@ -215,8 +237,8 @@ import java.text.MessageFormat;
  * predictable order. They try to find a translation that is appropriate for
  * your locale, starting with the fully qualified <code>LANG</code> variable
  * and then steadily degrading. For example, if your
- * <code>LANG=fr_CA.UTF-8</code>, you could expect the following sequence
- * of locales to be searched:
+ * <code>LANG=fr_CA.UTF-8</code>, you could expect the following sequence of
+ * locales to be searched:
  * 
  * <ul>
  * <li>fr_CA.UTF-8
@@ -230,10 +252,10 @@ import java.text.MessageFormat;
  * 
  * <p>
  * java-gnome uses the GNU <a
- * href="http://www.gnu.org/software/gettext/">gettext</a> suite, which is
- * the same translation infrastructure that GNOME and most other Linux
- * applications use. The process used by <code>gettext</code> to generate
- * the message catalogues is as follows:
+ * href="http://www.gnu.org/software/gettext/">gettext</a> suite, which is the
+ * same translation infrastructure that GNOME and most other Linux
+ * applications use. The process used by <code>gettext</code> to generate the
+ * message catalogues is as follows:
  * 
  * <p>
  * First of all, the messages used in your code need to be extracted. This is
@@ -273,19 +295,19 @@ import java.text.MessageFormat;
  * MO files are installed together with other application artifacts, usually
  * under
  * <code>/usr/share/locale/${locale}/LC_MESSAGES/${packageName}.mo</code>,
- * where <code>${locale}</code> is the locale and
- * <code>${packageName}</code> is a unique identifier for the program,
- * usually your application name. This name is needed because when installed
- * to the system, MO files are stored under a directory common to all
- * installed apps. For example, localized messages for the <code>pt_BR</code>
- * locale of the <code>myapp</code> application will be packaged as
+ * where <code>${locale}</code> is the locale and <code>${packageName}</code>
+ * is a unique identifier for the program, usually your application name. This
+ * name is needed because when installed to the system, MO files are stored
+ * under a directory common to all installed apps. For example, localized
+ * messages for the <code>pt_BR</code> locale of the <code>myapp</code>
+ * application will be packaged as
  * <code>/usr/share/locale/pt_BR/LC_MESSAGES/myapp.mo</code>.
  * 
  * <p>
  * As you can imagine, you will need to tell gettext where those files are
- * physically located. This is done with the
- * {@link #init(String, String) init()} method. This <b>must</b> be called
- * before any usage of java-gnome internationalization infrastructure.
+ * physically located. This is done with the {@link #init(String, String)
+ * init()} method. This <b>must</b> be called before any usage of java-gnome
+ * internationalization infrastructure.
  * 
  * <pre>
  * public void main(String[] args) {
@@ -373,8 +395,83 @@ public final class Internationalization
         }
     }
 
+    /**
+     * Translate a language name. For example, if you are in
+     * <code>LANG="es_ES.UTF-8"</code> and do:
+     * 
+     * <pre>
+     * lang = translateCountryName(&quot;Japanese&quot;);
+     * </pre>
+     * 
+     * you will get <code>"Japonés"</code>.
+     * 
+     * <p>
+     * In order to use this function, you must already have done the lookup of
+     * the ISO 639 language code (<code>jp</code> in this case to what the
+     * standard has the name in English as. Unfortunately there's no automated
+     * way to do this, however the <code>iso-codes</code> package countains an
+     * XML file at <code>/usr/share/xml/iso-codes/iso_639.xml</code> with this
+     * data.
+     * 
+     * <p>
+     * Beware that you really need to use the proper name; <code>es</code>
+     * (which is Spanish to mere mortals) is <code>"Spanish; Castilian"</code>
+     * in the XML data [and hence in the message catalogues].
+     * 
+     * <p>
+     * <i>This function uses</i> <code>dgetttext()</code> <i>and the</i>
+     * <code>"iso_639"</code> <i>translation domain. Translations for
+     * languages in this standard should already be available on your
+     * system.</i>
+     * 
+     * @since 4.0.17
+     */
+    public static final String translateLanguageName(String name) {
+        if (name == null) {
+            throw new IllegalArgumentException();
+        }
+
+        return dgettext("iso_639", name);
+    }
+
+    /**
+     * Translate a country name. For example, if you are in
+     * <code>LANG="fr_CA"</code>,
+     * 
+     * <pre>
+     * lang = translateCountryName(&quot;United Kingdom&quot;);
+     * </pre>
+     * 
+     * will get you <code>"Royaume-Uni"</code>.
+     * 
+     * <p>
+     * To use this function you must already have done the lookup of the ISO
+     * 3166 country code to its name in English. Unfortunately there's no
+     * automated way to do this. The <code>iso-codes</code> package, however,
+     * countains an XML file at
+     * <code>/usr/share/xml/iso-codes/iso_3166.xml</code> with the necessary
+     * data.
+     * 
+     * <p>
+     * <i>This function uses</i> <code>dgetttext()</code> <i>and the</i>
+     * <code>"iso_3166"</code> <i>translation domain. Translations for
+     * countries in this standard should already be available on your
+     * system.</i>
+     * 
+     * @since 4.0.17
+     */
+    public static final String translateCountryName(String name) {
+        if (name == null) {
+            throw new IllegalArgumentException();
+        }
+
+        return dgettext("iso_3166", name);
+    }
+
     private static native final String gettext(String msg);
 
+    private static native final String dgettext(String domain, String msg);
+
     /**
      * Mark the given message as translatable, without actually translating
      * it. This is used for static fields that are initialized before
@@ -419,7 +516,7 @@ public final class Internationalization
      * <pre>
      * public void main(String[] args) {
      *     Gtk.init(args);
-     *     Initialization.init(&quot;myapp&quot;, &quot;/usr/share/locale/&quot;);
+     *     Internationalization.init(&quot;myapp&quot;, &quot;/usr/share/locale/&quot;);
      *     ...
      * }
      * </pre>
