@@ -268,54 +268,17 @@ public class AboutDialog extends Dialog
         GtkAboutDialog.setTranslatorCredits(this, credits);
     }
 
-    private static class EmailClickHandler implements GtkAboutDialog.EmailClickedSignal
+    private static class ActivateLinkHandler implements GtkAboutDialog.ActivateLinkSignal
     {
-        private final EmailHook emailHook;
+        private final ActivateLink handler;
 
-        public EmailClickHandler(EmailHook emailHook) {
-            this.emailHook = emailHook;
+        public ActivateLinkHandler(ActivateLink handler) {
+            this.handler = handler;
         }
 
-        public void onEmailClicked(AboutDialog source, String email) {
-            emailHook.onEmailClicked(source, email);
-        }
-    }
-
-    /**
-     * Callback invoked when a email address is clicked.
-     * 
-     * @author Guillaume Mazoyer
-     * @since 4.0.14
-     * @deprecated Replaced by AboutDialog.ActivateLink
-     */
-    public interface EmailHook
-    {
-        public void onEmailClicked(AboutDialog source, String email);
-    }
-
-    /**
-     * Hookup the <code>AboutDialog.EmailHook</code> callback that will be
-     * used to handle email clicked actions.
-     * 
-     * @since 4.0.14
-     * @deprecated Replaced by connect(AboutDialog.ActivateLink)
-     */
-    public void setEmailCallback(EmailHook handler) {
-        GtkAboutDialogOverride.setEmailHook(this);
-        GtkAboutDialog.connect(this, new EmailClickHandler(handler), false);
-    }
-
-    private static class UrlClickHandler implements GtkAboutDialog.UrlClickedSignal
-    {
-        private final UrlHook urlHook;
-
-        public UrlClickHandler(UrlHook urlHook) {
-            this.urlHook = urlHook;
-        }
-
-        public void onUrlClicked(AboutDialog source, String link) {
+        public boolean onActivateLink(AboutDialog source, String link) {
             try {
-                urlHook.onUrlClicked(source, new URI(link));
+                return handler.onActivateLink(source, new URI(link));
             } catch (URISyntaxException e) {
                 throw new RuntimeException("We shouldn't be throwing this exception", e);
             }
@@ -326,23 +289,21 @@ public class AboutDialog extends Dialog
      * Callback invoked when the website is clicked.
      * 
      * @author Guillaume Mazoyer
-     * @since 4.0.14
-     * @deprecated Replaced by AboutDialog.ActivateLink
+     * @author Andrew Cowie
+     * @since 4.1.1
      */
-    public interface UrlHook
+    public interface ActivateLink
     {
-        public void onUrlClicked(AboutDialog source, URI link);
+        public boolean onActivateLink(AboutDialog source, URI link);
     }
 
     /**
-     * Hookup the <code>AboutDialog.UrlHook</code> callback that will be used
-     * to handle website button click actions.
+     * Hookup the <code>AboutDialog.ActivateLink</code> callback that will be
+     * used to handle website button click actions.
      * 
-     * @since 4.0.14
-     * @deprecated Replaced by connect(AboutDialog.ActivateLink)
+     * @since 4.1.1
      */
-    public void setUrlCallback(UrlHook handler) {
-        GtkAboutDialogOverride.setUrlHook(this);
-        GtkAboutDialog.connect(this, new UrlClickHandler(handler), false);
+    public void connect(AboutDialog.ActivateLink handler) {
+        GtkAboutDialog.connect(this, new ActivateLinkHandler(handler), false);
     }
 }
