@@ -1,13 +1,34 @@
 /*
- * Button.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2006-2008 Operational Dynamics Consulting Pty Ltd, and Others
- * 
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" plus the "Classpath Exception" (you may link to this code as a
- * library into other programs provided you don't make a derivation of it).
- * See the LICENCE file for the terms governing usage and redistribution.
+ * Copyright © 2006-2010 Operational Dynamics Consulting, Pty Ltd and Others
+ *
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
+ *
+ * Linking this library statically or dynamically with other modules is making
+ * a combined work based on this library. Thus, the terms and conditions of
+ * the GPL cover the whole combination. As a special exception (the
+ * "Claspath Exception"), the copyright holders of this library give you
+ * permission to link this library with independent modules to produce an
+ * executable, regardless of the license terms of these independent modules,
+ * and to copy and distribute the resulting executable under terms of your
+ * choice, provided that you also meet, for each linked independent module,
+ * the terms and conditions of the license of that module. An independent
+ * module is a module which is not derived from or based on this library. If
+ * you modify this library, you may extend the Classpath Exception to your
+ * version of the library, but you are not obligated to do so. If you do not
+ * wish to do so, delete this exception statement from your version.
  */
 package org.gnome.gtk;
 
@@ -33,7 +54,7 @@ package org.gnome.gtk;
  * @author Mario Torre
  * @since 4.0.0
  */
-public class Button extends Bin
+public class Button extends Bin implements Activatable
 {
     protected Button(long pointer) {
         super(pointer);
@@ -331,28 +352,6 @@ public class Button extends Bin
         GtkButton.connect(this, handler, false);
     }
 
-    /**
-     * @deprecated
-     */
-    public interface CLICKED extends GtkButton.ClickedSignal
-    {
-    }
-
-    /**
-     * @deprecated
-     */
-    public void connect(CLICKED handler) {
-        assert false : "use Button.Clicked instead";
-        GtkButton.connect(this, handler, false);
-    }
-
-    /*
-     * Button.Activate: "Applications should never connect to this signal, but
-     * use the 'clicked' signal."
-     * 
-     * Button.Entered, Button.Pressed, etc: deprecated.
-     */
-
     /**
      * Cause a <code>Button.Clicked</code> signal to be emitted.
      * 
@@ -374,4 +373,12 @@ public class Button extends Bin
     public void setFocusOnClick(boolean setting) {
         GtkButton.setFocusOnClick(this, setting);
     }
+
+    public void setRelatedAction(Action action) {
+        GtkActivatable.setRelatedAction(this, action);
+    }
+
+    public Action getRelatedAction() {
+        return GtkActivatable.getRelatedAction(this);
+    }
 }
