@@ -1,13 +1,34 @@
 /*
- * ImageMenuItem.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2007-2008 Operational Dynamics Consulting Pty Ltd
+ * Copyright © 2007-2011 Operational Dynamics Consulting, Pty Ltd
  *
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" plus the "Classpath Exception" (you may link to this code as a
- * library into other programs provided you don't make a derivation of it).
- * See the LICENCE file for the terms governing usage and redistribution.
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
+ *
+ * Linking this library statically or dynamically with other modules is making
+ * a combined work based on this library. Thus, the terms and conditions of
+ * the GPL cover the whole combination. As a special exception (the
+ * "Claspath Exception"), the copyright holders of this library give you
+ * permission to link this library with independent modules to produce an
+ * executable, regardless of the license terms of these independent modules,
+ * and to copy and distribute the resulting executable under terms of your
+ * choice, provided that you also meet, for each linked independent module,
+ * the terms and conditions of the license of that module. An independent
+ * module is a module which is not derived from or based on this library. If
+ * you modify this library, you may extend the Classpath Exception to your
+ * version of the library, but you are not obligated to do so. If you do not
+ * wish to do so, delete this exception statement from your version.
  */
 package org.gnome.gtk;
 
@@ -44,6 +65,9 @@ public class ImageMenuItem extends MenuItem
      * want. You can change the AccelGroup separately, but that's available to
      * support overriding the default accelerators. All in all this will need
      * updating.
+     * 
+     * From Azania: this should no longer need any updating unless you want to
+     * force the user to use the accelerator keybindings from the stock icon.
      */
     public ImageMenuItem(Stock stock) {
         super(GtkImageMenuItem.createImageMenuItemFromStock(stock.getStockId(), null));
@@ -59,12 +83,6 @@ public class ImageMenuItem extends MenuItem
         connect(handler);
     }
 
-    /** @deprecated */
-    public ImageMenuItem(Stock stock, MenuItem.ACTIVATE handler) {
-        this(stock);
-        connect(handler);
-    }
-
     /**
      * Create a MenuItem displaying an image next to text. When you have a
      * custom visual that is appropriate to show beside the label of a given
@@ -78,7 +96,8 @@ public class ImageMenuItem extends MenuItem
      * <p>
      * There is also a constructor which allows you to connect an
      * <code>MenuItem.Activate</code> handler in-line, see
-     * {@link ImageMenuItem#ImageMenuItem(Image, String, org.gnome.gtk.MenuItem.Activate) here}.
+     * {@link ImageMenuItem#ImageMenuItem(Image, String, org.gnome.gtk.MenuItem.Activate)
+     * here}.
      * 
      * @since 4.0.6
      */
@@ -99,13 +118,6 @@ public class ImageMenuItem extends MenuItem
         connect(handler);
     }
 
-    /** @deprecated */
-    public ImageMenuItem(Image image, String label, MenuItem.ACTIVATE handler) {
-        super(GtkImageMenuItem.createImageMenuItemWithMnemonic(label));
-        GtkImageMenuItem.setImage(this, image);
-        connect(handler);
-    }
-
     /**
      * Set the Image that will be used as an icon beside the text in the
      * ImageMenuItem.
@@ -121,4 +133,29 @@ public class ImageMenuItem extends MenuItem
     public void setImage(Image image) {
         GtkImageMenuItem.setImage(this, image);
     }
+
+    /**
+     * Force the icon accompanying this ImageMenuItem to always be shown,
+     * overriding the setting inherited from GtkSettings and GNOME.
+     * 
+     * <p>
+     * <i>As at GNOME 2.28, the default was changed by the `control-center`
+     * hackers to not show menu and button icons. This is very inconvenient,
+     * so you'll find yourself needing to call this frequently.</i>
+     * 
+     * @since 4.0.14
+     */
+    public void setAlwaysShowImage(boolean setting) {
+        GtkImageMenuItem.setAlwaysShowImage(this, setting);
+    }
+
+    /**
+     * Activate the key binding that comes with the stock configuration, for
+     * the case that this ImageMenuItem was constructed using a Stock item.
+     * 
+     * @since 4.0.16
+     */
+    public void setAccelerator(AcceleratorGroup group) {
+        GtkImageMenuItem.setAccelGroup(this, group);
+    }
 }
