@@ -1,13 +1,34 @@
 /*
- * StatusIcon.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2007 Operational Dynamics Consulting Pty Ltd, and Others
+ * Copyright © 2007-2011 Operational Dynamics Consulting, Pty Ltd and Others
  *
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" plus the "Classpath Exception" (you may link to this code as a
- * library into other programs provided you don't make a derivation of it).
- * See the LICENCE file for the terms governing usage and redistribution.
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
+ *
+ * Linking this library statically or dynamically with other modules is making
+ * a combined work based on this library. Thus, the terms and conditions of
+ * the GPL cover the whole combination. As a special exception (the
+ * "Claspath Exception"), the copyright holders of this library give you
+ * permission to link this library with independent modules to produce an
+ * executable, regardless of the license terms of these independent modules,
+ * and to copy and distribute the resulting executable under terms of your
+ * choice, provided that you also meet, for each linked independent module,
+ * the terms and conditions of the license of that module. An independent
+ * module is a module which is not derived from or based on this library. If
+ * you modify this library, you may extend the Classpath Exception to your
+ * version of the library, but you are not obligated to do so. If you do not
+ * wish to do so, delete this exception statement from your version.
  */
 package org.gnome.gtk;
 
@@ -31,13 +52,13 @@ import org.gnome.gdk.Pixbuf;
  * 
  * <p>
  * Using a StatusIcon in the notification area is generally less annoying than
- * popping up a {@link org.gnome.gtk.Dialog}, but they are also less likely
- * to catch user attention. Thus a StatusIcon can be used to inform the user
- * of an important event, but not necessarily an urgent event.
+ * popping up a {@link org.gnome.gtk.Dialog}, but they are also less likely to
+ * catch user attention. Thus a StatusIcon can be used to inform the user of
+ * an important event, but not necessarily an urgent event.
  * 
  * <p>
  * A StatusIcon can also have an associated tooltip, not to be confused with
- * {@link org.gnome.gtk.Tooltips}. This tooltip appears in a balloon at the
+ * {@link org.gnome.gtk.Tooltip}. This tooltip appears in a balloon at the
  * StatusIcon itself and can be used to convey additional information.
  * 
  * <p>
@@ -171,8 +192,8 @@ public class StatusIcon extends org.gnome.glib.Object
     /**
      * Returns the id of the stock icon being displayed by the StatusIcon. The
      * StorageType of the StatusIcon must be {@link ImageType#EMPTY EMPTY} or
-     * {@link ImageType#STOCK STOCK}; use
-     * {@link #getStorageType() getStorageType()} to find out which it is.
+     * {@link ImageType#STOCK STOCK}; use {@link #getStorageType()
+     * getStorageType()} to find out which it is.
      * 
      * @return the Stock representing of the stock icon being displayed by the
      *         StatusIcon or <code>null</code> if the StatusIcon is empty.
@@ -188,9 +209,10 @@ public class StatusIcon extends org.gnome.glib.Object
      * @param text
      *            a value of <code>null</code> will remove the tooltip if
      *            there is one presently set.
+     * @since 4.0.16
      */
-    public void setTooltip(String text) {
-        GtkStatusIcon.setTooltip(this, text);
+    public void setTooltipText(String text) {
+        GtkStatusIcon.setTooltipText(this, text);
     }
 
     /**
@@ -212,8 +234,8 @@ public class StatusIcon extends org.gnome.glib.Object
      * Widgets.
      * 
      * @param visible
-     *            <code>true</code> to show the StatusIcon,
-     *            <code>false</code> to hide it.
+     *            <code>true</code> to show the StatusIcon, <code>false</code>
+     *            to hide it.
      */
     /*
      * FIXME is that second sentence true?
@@ -222,37 +244,11 @@ public class StatusIcon extends org.gnome.glib.Object
         GtkStatusIcon.setVisible(this, visible);
     }
 
-    /**
-     * Reports if the StatusIcon is blinking.
-     */
-    public boolean getBlinking() {
-        return GtkStatusIcon.getBlinking(this);
-    }
-
-    /**
-     * Make the StatusIcon start [or stop] blinking.
-     * 
-     * <p>
-     * Note that blinking user interface elements may be problematic for some
-     * users and may be turned off on a desktop wide level, in which case this
-     * setting would have no effect. Even ignoring the accessibility question,
-     * many people find blinking StatusIcons annoying in general. Use
-     * sparingly, if at all.
-     * 
-     * @param setting
-     *            <code>true</code> to start the StatusIcon blinking,
-     *            <code>false</code> to stop it blinking.
-     */
-    public void setBlinking(boolean setting) {
-        GtkStatusIcon.setBlinking(this, setting);
-    }
-
     /**
      * Gets the size available for the image, in pixels. Stock icons adapt
      * their size automatically if the size of the notification area changes.
-     * For other storage types, the
-     * {@link StatusIcon.SIZE_CHANGED SIZE_CHANGED} signal can be used to
-     * react to size changes.
+     * For other storage types, the {@link StatusIcon.SizeChanged} signal can
+     * be used to react to size changes.
      */
     public int getSize() {
         return GtkStatusIcon.getSize(this);
@@ -281,7 +277,7 @@ public class StatusIcon extends org.gnome.glib.Object
     /*
      * FIXME any other ways?
      */
-    public interface ACTIVATE extends GtkStatusIcon.ACTIVATE
+    public interface Activate extends GtkStatusIcon.ActivateSignal
     {
         /**
          * The signal emitted when the user activates the StatusIcon.
@@ -292,22 +288,32 @@ public class StatusIcon extends org.gnome.glib.Object
         void onActivate(StatusIcon source);
     }
 
-    public void connect(ACTIVATE handler) {
-        GtkStatusIcon.connect(this, handler);
+    /**
+     * Hook up a <code>StatusIcon.Activate</code> handler
+     * 
+     * @since 4.0.4
+     */
+    public void connect(StatusIcon.Activate handler) {
+        GtkStatusIcon.connect(this, handler, false);
     }
 
     /**
      * The signal emitted when the user brings up the context menu of the
      * StatusIcon.
      */
-    public interface POPUP_MENU extends GtkStatusIcon.POPUP_MENU
+    public interface PopupMenu extends GtkStatusIcon.PopupMenuSignal
     {
         /**
-         * The signal emitted when the user brings up the context menu of the
-         * StatusIcon.
+         * The signal emitted when the user right-clicks on the StatusIcon.
+         * You're almost certain to want to be bringing up a context menu in
+         * that case, so see Menu's {@link Menu#popup(StatusIcon) popup()} for
+         * details of how to do it.
+         * 
+         * <p>
+         * The two additional parameters in the handler prototype are
+         * described below, but we disregard them and they may be removed in a
+         * future version of java-gnome.
          * 
-         * @param source
-         *            the object which received the signal.
          * @param button
          *            the button that was pressed, or 0 if the signal is not
          *            emitted in response to a button press event.
@@ -322,8 +328,8 @@ public class StatusIcon extends org.gnome.glib.Object
         void onPopupMenu(StatusIcon source, int button, int activateTime);
     }
 
-    public void connect(POPUP_MENU handler) {
-        GtkStatusIcon.connect(this, handler);
+    public void connect(StatusIcon.PopupMenu handler) {
+        GtkStatusIcon.connect(this, handler, false);
     }
 
     /**
@@ -331,7 +337,7 @@ public class StatusIcon extends org.gnome.glib.Object
      * changes. This happens if the panel the Notification Area applet is
      * running in gets resized.
      */
-    public interface SIZE_CHANGED extends GtkStatusIcon.SIZE_CHANGED
+    public interface SizeChanged extends GtkStatusIcon.SizeChangedSignal
     {
         /**
          * Signal emitted when the size available for the image changes.
@@ -344,7 +350,7 @@ public class StatusIcon extends org.gnome.glib.Object
         boolean onSizeChanged(StatusIcon source, int size);
     }
 
-    public void connect(SIZE_CHANGED handler) {
-        GtkStatusIcon.connect(this, handler);
+    public void connect(StatusIcon.SizeChanged handler) {
+        GtkStatusIcon.connect(this, handler, false);
     }
 }
