@@ -1,13 +1,34 @@
 /*
- * Statusbar.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2007 Operational Dynamics Consulting Pty Ltd
+ * Copyright © 2007-2011 Operational Dynamics Consulting, Pty Ltd
  *
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" plus the "Classpath Exception" (you may link to this code as a
- * library into other programs provided you don't make a derivation of it).
- * See the LICENCE file for the terms governing usage and redistribution.
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
+ *
+ * Linking this library statically or dynamically with other modules is making
+ * a combined work based on this library. Thus, the terms and conditions of
+ * the GPL cover the whole combination. As a special exception (the
+ * "Claspath Exception"), the copyright holders of this library give you
+ * permission to link this library with independent modules to produce an
+ * executable, regardless of the license terms of these independent modules,
+ * and to copy and distribute the resulting executable under terms of your
+ * choice, provided that you also meet, for each linked independent module,
+ * the terms and conditions of the license of that module. An independent
+ * module is a module which is not derived from or based on this library. If
+ * you modify this library, you may extend the Classpath Exception to your
+ * version of the library, but you are not obligated to do so. If you do not
+ * wish to do so, delete this exception statement from your version.
  */
 package org.gnome.gtk;
 
@@ -119,29 +140,6 @@ public class Statusbar extends HBox
         GtkStatusbar.push(this, 0, "");
     }
 
-    /**
-     * Set whether or not the Statusbar has a visual marking at its right hand
-     * side indicating whether or not it can be resized and acting as a
-     * convenient target to click on.
-     * 
-     * <p>
-     * As the default for this is <code>true</code>, you only need to call
-     * this if you want to suppress the resize handle from being drawn. Note
-     * that this is just a visual cue; the actual resize behaviour is governed
-     * by the window manager in concert with the Window's <var>resizable</var>
-     * property. See {@link Window#setResizable(boolean) setResizable()}.
-     * 
-     * <p>
-     * As a very rough guide, main application Windows really ought to have
-     * the resize grip; fancy custom popups filling some transient purpose
-     * that just happen to have a Statusbar can do without them.
-     * 
-     * @since 4.0.6
-     */
-    public void setHasResizeGrip(boolean setting) {
-        GtkStatusbar.setHasResizeGrip(this, setting);
-    }
-
     /**
      * Set the message showing in the Statusbar. You can call this frequently
      * with whatever indication you wish to display to the user; the last
