@@ -1016,14 +1016,6 @@ public class TextView extends Container
         GtkTextView.setRightMargin(this, pixels);
     }
 
-    /**
-     * @deprecated
-     */
-    public void setLeftMargin(int pixels) {
-        assert false : "use setMarginLeft() instead";
-        GtkTextView.setLeftMargin(this, pixels);
-    }
-
     /**
      * Create and attach a {@link Spell} object to the view to add
      * spellchecking capability.
@@ -1085,7 +1077,8 @@ public class TextView extends Container
     }
 
     /**
-     * Tell this TextView to adopt the given justification.
+     * Tell this TextView to adopt the given justification. This is probably
+     * what you think of as "alignment".
      * 
      * @since 4.0.14
      */
