@@ -152,14 +152,6 @@ public class ToggleAction extends Action
         super(GtkToggleAction.createToggleAction(name, label, null, null));
     }
 
-    /**
-     * @deprecated
-     */
-    public void toggled() {
-        assert false : "Use emitToggled() instead";
-        GtkToggleAction.toggled(this);
-    }
-
     /**
      * Emit the <code>ToggleAction.Toggled</code> signal.
      * 
