@@ -1,13 +1,34 @@
 /*
- * ToggleToolButton.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2007 Operational Dynamics Consulting Pty Ltd, and Others
+ * Copyright © 2007-2010 Operational Dynamics Consulting, Pty Ltd and Others
  *
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" plus the "Classpath Exception" (you may link to this code as a
- * library into other programs provided you don't make a derivation of it).
- * See the LICENCE file for the terms governing usage and redistribution.
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
+ *
+ * Linking this library statically or dynamically with other modules is making
+ * a combined work based on this library. Thus, the terms and conditions of
+ * the GPL cover the whole combination. As a special exception (the
+ * "Claspath Exception"), the copyright holders of this library give you
+ * permission to link this library with independent modules to produce an
+ * executable, regardless of the license terms of these independent modules,
+ * and to copy and distribute the resulting executable under terms of your
+ * choice, provided that you also meet, for each linked independent module,
+ * the terms and conditions of the license of that module. An independent
+ * module is a module which is not derived from or based on this library. If
+ * you modify this library, you may extend the Classpath Exception to your
+ * version of the library, but you are not obligated to do so. If you do not
+ * wish to do so, delete this exception statement from your version.
  */
 package org.gnome.gtk;
 
@@ -47,6 +68,8 @@ public class ToggleToolButton extends ToolButton
 
     /**
      * Create a new ToggleToolButton.
+     * 
+     * @since 4.0.4
      */
     public ToggleToolButton() {
         super(GtkToggleToolButton.createToggleToolButton());
@@ -54,6 +77,8 @@ public class ToggleToolButton extends ToolButton
 
     /**
      * Create a new ToggleToolButton based on one of the stock items.
+     * 
+     * @since 4.0.4
      */
     public ToggleToolButton(Stock stock) {
         super(GtkToggleToolButton.createToggleToolButtonFromStock(stock.getStockId()));
@@ -63,6 +88,8 @@ public class ToggleToolButton extends ToolButton
      * Set whether this ToggleToolButton is active, that is, whether it
      * appears pressed or not. Calling this will emit a <code>TOGGLED</code>
      * signal.
+     * 
+     * @since 4.0.4
      */
     public void setActive(boolean isActive) {
         GtkToggleToolButton.setActive(this, isActive);
@@ -70,6 +97,8 @@ public class ToggleToolButton extends ToolButton
 
     /**
      * Is the ToggleToolButton currently activated on?
+     * 
+     * @since 4.0.4
      */
     public boolean getActive() {
         return GtkToggleToolButton.getActive(this);
@@ -77,16 +106,20 @@ public class ToggleToolButton extends ToolButton
 
     /**
      * Signal indicating the ToggleToolButton state has changed.
+     * 
+     * @since 4.0.4
      */
-    public interface TOGGLED extends GtkToggleToolButton.TOGGLED
+    public interface Toggled extends GtkToggleToolButton.ToggledSignal
     {
         public void onToggled(ToggleToolButton source);
     }
 
     /**
-     * Connect a handler to the <code>TOGGLED</code> signal.
+     * Connect a handler to the <code>ToggleToolButton.Toggled</code> signal.
+     * 
+     * @since 4.0.4
      */
-    public void connect(TOGGLED handler) {
-        GtkToggleToolButton.connect(this, handler);
+    public void connect(ToggleToolButton.Toggled handler) {
+        GtkToggleToolButton.connect(this, handler, false);
     }
 }
