@@ -1,7 +1,7 @@
 /*
  * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright © 2007-2010 Operational Dynamics Consulting, Pty Ltd
+ * Copyright © 2007-2011 Operational Dynamics Consulting, Pty Ltd
  * Copyright © 2007-2009 Vreixo Formoso
  *
  * The code in this file, and the program it is a part of, is made available
@@ -61,7 +61,7 @@ package org.gnome.gtk;
  * @author Andrew Cowie
  * @since 4.0.4
  */
-public class Toolbar extends Container
+public class Toolbar extends Container implements Orientable
 {
     protected Toolbar(long pointer) {
         super(pointer);
@@ -106,11 +106,16 @@ public class Toolbar extends Container
      * a vertical orientation can become useful as a technique to make a
      * better usage of the available screen real estate.
      * 
-     * @deprecated This has been replaced in GTK 2.16
+     * @since 4.1.1
      */
     public void setOrientation(Orientation orientation) {
-        // no-op until GTK 2.16 available.
+        GtkOrientable.setOrientation(this, orientation);
     }
+    
+    public Orientation getOrientation() {
+        return GtkOrientable.getOrientation(this);
+    }
+
 
     /**
      * Set the appearance of a Toolbar.
@@ -140,16 +145,4 @@ public class Toolbar extends Container
     public void setStyle(ToolbarStyle style) {
         GtkToolbar.setStyle(this, style);
     }
-
-    /**
-     * @deprecated This is now a toolkit wide policy setting, and no longer
-     *             individually controllable via this method. We've made this
-     *             a no-op.
-     */
-    /*
-     * As of GTK 2.14, gtk_toolbar_set_tooltips() is deprecated, and replaced
-     * by "gtk-enable-tooltips" via GtkSettings. We don't need to expose this
-     * here anymore.
-     */
-    public void setTooltips(boolean enable) {}
 }
