@@ -33,12 +33,9 @@
 package org.gnome.gtk;
 
 import org.freedesktop.cairo.Context;
-import org.gnome.gdk.Color;
-import org.gnome.gdk.Colormap;
 import org.gnome.gdk.Event;
 import org.gnome.gdk.EventButton;
 import org.gnome.gdk.EventCrossing;
-import org.gnome.gdk.EventExpose;
 import org.gnome.gdk.EventFocus;
 import org.gnome.gdk.EventKey;
 import org.gnome.gdk.EventMask;
@@ -46,6 +43,7 @@ import org.gnome.gdk.EventMotion;
 import org.gnome.gdk.EventScroll;
 import org.gnome.gdk.EventVisibility;
 import org.gnome.gdk.RGBA;
+import org.gnome.gdk.Rectangle;
 import org.gnome.gdk.VisibilityState;
 import org.gnome.pango.FontDescription;
 
@@ -60,7 +58,7 @@ import org.gnome.pango.FontDescription;
  * @author Vreixo Formoso
  * @since 4.0.0
  */
-public abstract class Widget extends org.gnome.gtk.Object
+public abstract class Widget extends org.gnome.glib.Object
 {
     protected Widget(long pointer) {
         super(pointer);
@@ -202,7 +200,7 @@ public abstract class Widget extends org.gnome.gtk.Object
 
     /**
      * Request that an area of the Widget to be redrawn. This will eventually
-     * result in an <code>Widget.ExposeEvent</code> being sent to the Widget
+     * result in an <code>Widget.Draw</code> signal being sent to the Widget
      * asking it to [re]render the area given by the passed in co-ordinates.
      * 
      * <p>
@@ -212,7 +210,7 @@ public abstract class Widget extends org.gnome.gtk.Object
      * <p>
      * The redraw will not happen immediately, but rather during the next
      * iteration of the main loop. Also, note that several such requests may
-     * be combined into a single <code>Widget.ExposeEvent</code> by the X
+     * be combined into a single <code>Widget.Draw</code> signal by the X
      * server and GDK.
      * 
      * <p>
@@ -264,17 +262,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface ENTER_NOTIFY_EVENT extends GtkWidget.EnterNotifyEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(ENTER_NOTIFY_EVENT handler) {
-        assert false : "use Widget.EnterNotifyEvent instead";
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * Signal emitted when the mouse pointer leaves the Widget.
      * 
@@ -296,17 +283,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface LEAVE_NOTIFY_EVENT extends GtkWidget.LeaveNotifyEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(LEAVE_NOTIFY_EVENT handler) {
-        assert false : "use Widget.LeaveNotifyEvent instead";
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * Signal emitted when the <i>keyboard</i> focus leaves this Widget. Focus
      * is a concept that is shared evenly between the widget toolkit and the
@@ -331,17 +307,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface FOCUS_OUT_EVENT extends GtkWidget.FocusOutEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(FOCUS_OUT_EVENT handler) {
-        assert false : "use Widget.FocusOutEvent instead";
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * Signal emitted when focus enters this Widget. See
      * {@link Widget.FocusOutEvent}.
@@ -363,17 +328,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface FOCUS_IN_EVENT extends GtkWidget.FocusInEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(FOCUS_IN_EVENT handler) {
-        assert false : "use Widget.FocusInEvent instead";
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * The signal emitted when a portion or all of the Widget has been exposed
      * and needs [re]drawing. This can happen when a Widget is first realized
@@ -381,35 +335,9 @@ public abstract class Widget extends org.gnome.gtk.Object
      * another Window or because it was offscreen).
      * 
      * <p>
-     * The <code>event</code> parameter to the callback contains information
-     * about the size of the region that was damaged or otherwise needs
-     * redrawing. For instance, if you just wanted to know what area was
-     * exposed, you could do:
-     * 
-     * <pre>
-     * foo.connect(new Widget.ExposeEvent() {
-     *     public boolean onExposeEvent(Widget source, EventExpose event) {
-     *         Rectangle rect;
-     *         int width, height, x, y;
-     *         
-     *         rect = event.getArea();
-     *         
-     *         width = rect.getWidth();
-     *         height = rect.getHeight();
-     *         x = rect.getX();
-     *         y = rect.getY();
-     *         
-     *         System.out.println(width + &quot;x&quot; + height + &quot; at &quot; + x + &quot;,&quot; + y);
-     *     }
-     * }
-     * </pre>
-     * 
-     * <p>
-     * The real purpose of <code>Widget.ExposeEvent</code>, however, is to be
-     * the the gateway to drawing. GNOME uses the excellent <a
-     * href="http://www.cairographics.org/">Cairo 2D graphics library</a> to
-     * draw its user interfaces, which we make available in java-gnome in
-     * package <code>org.freedesktop.cairo</code>.
+     * GNOME uses the excellent <a href="http://www.cairographics.org/">Cairo
+     * 2D graphics library</a> to draw its user interfaces, which we make
+     * available in java-gnome in package <code>org.freedesktop.cairo</code>.
      * 
      * <p>
      * Code that does drawing needs to be written a little differently than
@@ -420,61 +348,9 @@ public abstract class Widget extends org.gnome.gtk.Object
      * for drawing operations, Cairo needs the details of the [org.gnome.gdk]
      * Display, Screen and Window it will be drawing to, and these are not
      * available until the Widget has been realized and mapped. The
-     * <code>Widget.ExposeEvent</code> signal is emitted exactly at this
-     * point, and so that's when we have the environment we need to do our
-     * drawing.
+     * <code>Widget.Draw</code> signal is emitted exactly at this point, and
+     * so that's when we have the environment we need to do our drawing.
      * 
-     * <p>
-     * To do drawing with Cairo you need a Context. You can instantiate one by
-     * passing the EventExpose object to the Context constructor:
-     * 
-     * <pre>
-     * foo.connect(new Widget.ExposeEvent() {
-     *     public boolean onExposeEvent(Widget source, EventExpose event) {
-     *         Context cr;
-     *         
-     *         cr = new Context(event);
-     *         
-     *         // start drawing
-     *     }
-     * }
-     * </pre>
-     * 
-     * Obviously from here you can carry on using the Cairo Graphics library
-     * to do your custom drawing. See {@link org.freedesktop.cairo.Context
-     * Context} for further details.
-     * 
-     * @author Andrew Cowie
-     * @since 4.0.7
-     * @deprecated GTK 3 has replaced the <code>Widget.ExposeEvent</code>
-     *             signal with a new {@link Widget.Draw} instead.
-     */
-    /*
-     * FIXME when we figure out offscreen drawing, then we can change "cannot
-     * easily do".
-     */
-    public interface ExposeEvent extends GtkWidget.ExposeEventSignal
-    {
-        /**
-         * As with other event signals, the boolean return value indicates
-         * whether or not you wish to block further emission of the signal. In
-         * general you want to leave the default handlers alone; let them run
-         * as well. Return <code>false</code>.
-         */
-        public boolean onExposeEvent(Widget source, EventExpose event);
-    }
-
-    /**
-     * Hook up a handler to receive <code>Widget.ExposeEvent</code> signals on
-     * this Widget.
-     * 
-     * @since 4.0.7
-     */
-    public void connect(Widget.ExposeEvent handler) {
-        GtkWidget.connect(this, handler, false);
-    }
-
-    /**
      * <p>
      * To do drawing with Cairo you need a Context, and GTK 3 conveniently
      * provides you with one all ready to go:
@@ -491,43 +367,14 @@ public abstract class Widget extends org.gnome.gtk.Object
      * <code>restore()</code> around the <code>Widget.Draw</code> signal so
      * you don't worry about having to reset the Context to its initial state.
      * 
-     * <p>
-     * <i>This simulates GTK 3's 'draw' signal as an aide to porting.</i>
-     * 
-     * 
      * @author Andrew Cowie
      * @since 4.0.20
      */
-    public interface Draw
+    public interface Draw extends GtkWidget.DrawSignal
     {
         public boolean onDraw(Widget source, Context cr);
     }
 
-    /*
-     * Temporary workaround. Remove on '4.1' branch
-     */
-    private static class DrawAdapter implements GtkWidget.ExposeEventSignal
-    {
-        private Widget.Draw handler;
-
-        private DrawAdapter(Widget.Draw handler) {
-            this.handler = handler;
-        }
-
-        public boolean onExposeEvent(Widget source, EventExpose event) {
-            final Context cr;
-            final boolean result;
-
-            cr = new Context(event);
-
-            cr.save();
-            result = handler.onDraw(source, cr);
-            cr.restore();
-
-            return result;
-        }
-    }
-
     /**
      * Hook up a handler to receive <code>Widget.Draw</code> signals on this
      * Widget.
@@ -535,17 +382,6 @@ public abstract class Widget extends org.gnome.gtk.Object
      * @since 4.0.20
      */
     public void connect(Widget.Draw handler) {
-        GtkWidget.connect(this, new DrawAdapter(handler), false);
-    }
-
-    /** @deprecated */
-    public interface EXPOSE_EVENT extends GtkWidget.ExposeEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(EXPOSE_EVENT handler) {
-        assert false : "use Widget.ExposeEvent instead";
         GtkWidget.connect(this, handler, false);
     }
 
@@ -618,17 +454,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface KEY_PRESS_EVENT extends GtkWidget.KeyPressEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(KEY_PRESS_EVENT handler) {
-        assert false : "use Widget.KeyPressEvent instead";
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * Handler interface for key release events. Calling
      * {@link EventKey#getKeyval() getKeyval()} on the <code>event</code>
@@ -657,16 +482,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface KEY_RELEASE_EVENT extends GtkWidget.KeyReleaseEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(KEY_RELEASE_EVENT handler) {
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * Signal emitted when the user turns the mouse wheel.
      * 
@@ -939,146 +754,34 @@ public abstract class Widget extends org.gnome.gtk.Object
         return GtkWidget.getWindow(this);
     }
 
-    /**
-     * Sets the Colormap of this widget.
-     * 
-     * <p>
-     * The only useful application of this is to enable per-pixel translucency
-     * on top level Widgets. This involves getting the RGBA colormap from the
-     * associated screen, and also requires (if using cairo) using the clear
-     * operator to remove the standard background.
-     * 
-     * @since 4.0.10
-     * @deprecated Removed from GTK 3.
-     */
-    public void setColormap(Colormap colormap) {
-        GtkWidget.setColormap(this, colormap);
-    }
-
     /**
      * Adjust the background colour being used when drawing this Widget. This
      * leaves all other style properties unchanged.
      * 
-     * <p>
-     * If you need to change the background colour behind the text in an Entry
-     * or TextView, see {@link #modifyBase(Widget, StateType Color)
-     * modifyBase()}.
-     * 
-     * <p>
-     * This is one of a family of "<code>modify</code>" methods; see
-     * {@link #modifyStyle(Widget, RcStyle) modifyStyle()} for further details
-     * about the interaction of the various theming and style mechanisms.
-     * 
-     * @since 4.0.5
-     * @deprecated This has been replaced in 4.1 with
-     *             <code>overrideBackground()</code>.
-     */
-    public void modifyBackground(StateType state, Color color) {
-        GtkWidget.modifyBg(this, state, color);
-    }
-
-    /**
      * @since 4.0.20
      */
     public void overrideBackground(StateFlags state, RGBA color) {
-        final StateType type;
-
-        if (state == StateFlags.ACTIVE) {
-            type = StateType.ACTIVE;
-        } else if (state == StateFlags.INSENSITIVE) {
-            type = StateType.INSENSITIVE;
-        } else if (state == StateFlags.NORMAL) {
-            type = StateType.NORMAL;
-        } else if (state == StateFlags.PRELIGHT) {
-            type = StateType.PRELIGHT;
-        } else if (state == StateFlags.SELECTED) {
-            type = StateType.SELECTED;
-        } else {
-            throw new AssertionError();
-        }
-
-        GtkWidget.modifyBg(this, type, color.getActual());
-    }
-
-    /**
-     * Set the colour used for text background on this Widget. To change the
-     * foreground colour of the text, use
-     * {@link #modifyText(StateType, Color) modifyText()}.
-     * 
-     * <p>
-     * This is one of a family of "<code>modify</code>" methods; see
-     * {@link #modifyStyle(Widget, RcStyle) modifyStyle()} for further details
-     * about the interaction of the various theming and style mechanisms.
-     * 
-     * @since 4.0.8
-     * @deprecated This has been replaced in 4.1 with
-     *             <code>overrideFont()</code>.
-     */
-    public void modifyBase(StateType state, Color color) {
-        GtkWidget.modifyBase(this, state, color);
+        GtkWidget.overrideBackgroundColor(this, state, color);
     }
 
     /**
      * Set the colour used for text rendered by this Widget. This is the
      * foreground colour; to change the background colour behind text use
-     * {@link #modifyBase(StateType, Color) modifyBase()}.
+     * {@link #overrideBackground(StateFlags, RGBA) overrideBackground()}.
      * 
-     * <p>
-     * This is one of a family of "<code>modify</code>" methods; see
-     * {@link #modifyStyle(Widget, RcStyle) modifyStyle()} for further details
-     * about the interaction of the various theming and style mechanisms.
-     * 
-     * @since 4.0.6
-     * @deprecated This has been replaced in 4.1 with
-     *             <code>overrideColor()</code>.
-     */
-    public void modifyText(StateType state, Color color) {
-        GtkWidget.modifyText(this, state, color);
-    }
-
-    /**
      * @since 4.0.20
      */
     public void overrideColor(StateFlags state, RGBA color) {
-        final StateType type;
-
-        if (state == StateFlags.ACTIVE) {
-            type = StateType.ACTIVE;
-        } else if (state == StateFlags.INSENSITIVE) {
-            type = StateType.INSENSITIVE;
-        } else if (state == StateFlags.NORMAL) {
-            type = StateType.NORMAL;
-        } else if (state == StateFlags.PRELIGHT) {
-            type = StateType.PRELIGHT;
-        } else if (state == StateFlags.SELECTED) {
-            type = StateType.SELECTED;
-        } else {
-            throw new AssertionError();
-        }
-
-        GtkWidget.modifyText(this, type, color.getActual());
+        GtkWidget.overrideColor(this, state, color);
     }
 
     /**
      * Set the font used for text rendered by this Widget.
      * 
-     * <p>
-     * This is one of a family of "<code>modify</code>" methods.
-     * 
-     * @since 4.0.10
-     * @deprecated This has been replaced in 4.1 with
-     *             {@link #overrideFont(FontDescription) overrideFont()}
-     *             </code>.
-     */
-    public void modifyFont(FontDescription desc) {
-        GtkWidget.modifyFont(this, desc);
-    }
-
-    /**
      * @since 4.0.20
      */
     public void overrideFont(FontDescription desc) {
-        GtkWidget.modifyFont(this, desc);
+        GtkWidget.overrideFont(this, desc);
     }
 
     /**
@@ -1134,18 +837,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface VISIBILITY_NOTIFY_EVENT extends GtkWidget.VisibilityNotifyEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(VISIBILITY_NOTIFY_EVENT handler) {
-        assert false : "use Widget.VisibilityNotifyEvent instead";
-        GtkWidget.addEvents(this, EventMask.VISIBILITY_NOTIFY);
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * The signal emitted when a Window becomes invisible. This happens in a
      * variety of scenarios, notably when the Window is minimized, when you
@@ -1228,17 +919,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface UNMAP_EVENT extends GtkWidget.UnmapEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(UNMAP_EVENT handler) {
-        assert false : "use Widget.UnmapEvent instead";
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * Does this Widget currently have the keyboard focus?
      * 
@@ -1309,17 +989,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface HIDE extends GtkWidget.HideSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(HIDE handler) {
-        assert false : "use Widget.Hide instead";
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * Make this Widget have the keyboard focus for the Window it is within.
      * 
@@ -1396,10 +1065,12 @@ public abstract class Widget extends org.gnome.gtk.Object
      * so that we get the same Pointer object back if multiple calls are made
      * to getRequisition() and getAllocation(), thus creating a Proxy like
      * behaviour even though these are Boxeds. This avoids allocating
-     * duplicates but the real point is that these objects are "live" and so
-     * we want to refer to the real structs in GtkWidget.
+     * duplicates.
      */
 
+    /*
+     * This requisition will need to be removed when GTK3 arrives
+     */
     private Requisition requisition;
 
     private Allocation allocation;
@@ -1417,16 +1088,11 @@ public abstract class Widget extends org.gnome.gtk.Object
      */
     public Allocation getAllocation() {
         if (allocation == null) {
-            allocation = GtkWidgetOverride.getAllocation(this);
-
-            /*
-             * We are making a live reference to the GtkAllocation struct
-             * member in the GtkWidget class, so we need to make sure that our
-             * Allocation Proxy does not survive longer than the Widget. We
-             * use this back reference for this purpose.
-             */
-            allocation.widget = this;
+            allocation = new Allocation();
         }
+
+        GtkWidgetOverride.getAllocation(this, allocation);
+
         return allocation;
     }
 
@@ -1441,29 +1107,143 @@ public abstract class Widget extends org.gnome.gtk.Object
      * implies that the request calculation won't have any effect if the
      * Widget is not yet been FIXME to a Screen).
      * 
-     * <p>
-     * <i>Implementation note: calling this method will invoke
-     * <code>gtk_widget_size_request()</code>. The returned Requisition object
-     * is "live" however, so once you've got it you can use its getter methods
-     * freely without needing to keep calling this method.</i>
-     * 
      * @since 4.0.6
      */
     public Requisition getRequisition() {
         if (requisition == null) {
-            requisition = GtkWidgetOverride.getRequisition(this);
-
-            /*
-             * We are making a live reference to the GtkRequisition struct
-             * member in the GtkWidget class, so we need to make sure that our
-             * Requisition Proxy does not survive longer than the Widget. We
-             * use this back reference for this purpose.
-             */
-            requisition.widget = this;
+            requisition = new Requisition();
         }
+
+        GtkWidgetOverride.getRequisition(this, requisition);
+
         return requisition;
     }
 
+    /**
+     * Retreive the width that has been allocated to this Widget, in pixels.
+     * This is meant to be used by <code>Widget.Draw</code> handlers when they
+     * need to know their canvas size.
+     * 
+     * @since 4.1.1
+     */
+    public int getAllocatedWidth() {
+        return GtkWidget.getAllocatedWidth(this);
+    }
+
+    /**
+     * Retreive the height that has been allocated to this Widget. See also
+     * {@link #getAllocatedWidth() getAllocatedWidth()}.
+     * 
+     * @since 4.1.1
+     */
+    public int getAllocatedHeight() {
+        return GtkWidget.getAllocatedHeight(this);
+    }
+
+    /**
+     * @since 4.1.1
+     */
+    public int getPreferredWidthNatural() {
+        final int[] natural;
+
+        natural = new int[1];
+
+        GtkWidget.getPreferredWidth(this, null, natural);
+
+        return natural[0];
+    }
+
+    /**
+     * @since 4.1.1
+     */
+    public int getPreferredWidthMinimum() {
+        final int[] minimum;
+
+        minimum = new int[1];
+
+        GtkWidget.getPreferredWidth(this, minimum, null);
+
+        return minimum[0];
+    }
+
+    /**
+     * @since 4.1.1
+     */
+    public int getPreferredHeightMinimum() {
+        final int[] minimum;
+
+        minimum = new int[1];
+
+        GtkWidget.getPreferredHeight(this, minimum, null);
+
+        return minimum[0];
+    }
+
+    /**
+     * @since 4.1.1
+     */
+    public int getPreferredHeightNatural() {
+        final int[] natural;
+
+        natural = new int[1];
+
+        GtkWidget.getPreferredHeight(this, null, natural);
+
+        return natural[0];
+    }
+
+    /**
+     * @since 4.1.1
+     */
+    public int getPreferredHeightForWidthMinimum(int width) {
+        final int[] minimum;
+
+        minimum = new int[1];
+
+        GtkWidget.getPreferredHeightForWidth(this, width, minimum, null);
+
+        return minimum[0];
+    }
+
+    /**
+     * @since 4.1.1
+     */
+    public int getPreferredHeightForWidthNatural(int width) {
+        final int[] natural;
+
+        natural = new int[1];
+
+        GtkWidget.getPreferredHeightForWidth(this, width, null, natural);
+
+        return natural[0];
+    }
+
+    /**
+     * @since 4.1.1
+     */
+    public int getPreferredWidthForHeightMinimum(int height) {
+        final int[] minimum;
+
+        minimum = new int[1];
+
+        GtkWidget.getPreferredWidthForHeight(this, height, minimum, null);
+
+        return minimum[0];
+    }
+
+    /**
+     * @since 4.1.1
+     */
+    public int getPreferredWidthForHeightNatural(int height) {
+        final int[] natural;
+
+        natural = new int[1];
+
+        GtkWidget.getPreferredWidthForHeight(this, height, null, natural);
+
+        return natural[0];
+    }
+
     /**
      * Signal fired when the user clicks one of their mouse buttons.
      * 
@@ -1519,17 +1299,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface BUTTON_PRESS_EVENT extends GtkWidget.ButtonPressEventSignal
-    {
-    }
-
-    /** @deprecated */
-    public void connect(Widget.BUTTON_PRESS_EVENT handler) {
-        assert false : "use Widget.ButtonPressEvent instead";
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * The signal emitted when the user releases a pressed mouse button. See
      * {@link Widget.ButtonPressEvent} for discussion of this set of event
@@ -1552,18 +1321,6 @@ public abstract class Widget extends org.gnome.gtk.Object
         GtkWidget.connect(this, handler, false);
     }
 
-    /** @deprecated */
-    public interface BUTTON_RELEASE_EVENT extends GtkWidget.ButtonReleaseEventSignal
-    {
-        public boolean onButtonReleaseEvent(Widget source, EventButton event);
-    }
-
-    /** @deprecated */
-    public void connect(Widget.BUTTON_RELEASE_EVENT handler) {
-        assert false : "use Widget.ButtonReleaseEvent instead";
-        GtkWidget.connect(this, handler, false);
-    }
-
     /**
      * Whether the Widget can (is willing to) accept the keyboard input focus.
      * There's no default, as such; Widgets able to take keyboard focus will
@@ -1676,12 +1433,12 @@ public abstract class Widget extends org.gnome.gtk.Object
      * 
      * <p>
      * This can be used as an indication that your Window is no longer
-     * minimized. Connecting to {@link Widget.ExposeEvent} would probably tell
-     * you what you need to know, but if all you want to do is find out your
-     * app is [back] onscreen then <code>Widget.ExposeEvent</code> would be a
-     * bit heavy handed. Of course, if you are drawing anyway, then it's fine.
-     * See {@link Widget.UnmapEvent} for examples of other variations on the
-     * theme of tracking the state of your application.
+     * minimized. Connecting to {@link Widget.Draw} would probably tell you
+     * what you need to know, but if all you want to do is find out your app
+     * is [back] onscreen then <code>Widget.Draw</code> would be a bit heavy
+     * handed. Of course, if you are drawing anyway, then it's fine. See
+     * {@link Widget.UnmapEvent} for examples of other variations on the theme
+     * of tracking the state of your application.
      * 
      * <p>
      * <i>The interaction between the GTK library we use, its underlying GDK
@@ -1784,9 +1541,9 @@ public abstract class Widget extends org.gnome.gtk.Object
      * 
      * <p>
      * Almost anything that you would do that would invole you needing an
-     * [org.gnome.gdk] Window is best done in a
-     * <code>Widget.ExposeEvent</code> handler, at which point the Widget is
-     * already realized, mapped, and showing.
+     * [org.gnome.gdk] Window is best done in a <code>Widget.Draw</code>
+     * handler, at which point the Widget is already realized, mapped, and
+     * showing.
      * 
      * @since 4.0.16
      */
@@ -1929,14 +1686,10 @@ public abstract class Widget extends org.gnome.gtk.Object
      * <code>null</code> it out to to release the strong reference to the
      * object.
      * 
-     * <p>
-     * <i>This is a GTK 3.0 signal, we've presented it here as aide to
-     * porting</i>
-     * 
      * @author Andrew Cowie
      * @since 4.0.20
      */
-    public interface Destroy
+    public interface Destroy extends GtkWidget.DestroySignal
     {
         /**
          * Release any references you hold to the given <code>source</code>
@@ -1945,25 +1698,98 @@ public abstract class Widget extends org.gnome.gtk.Object
         public void onDestroy(Widget source);
     }
 
-    private static class DestroyAdapter implements GtkObject.DestroySignal
-    {
-        private Widget.Destroy handler;
-
-        private DestroyAdapter(Widget.Destroy handler) {
-            this.handler = handler;
-        }
-
-        public void onDestroy(Object source) {
-            handler.onDestroy((Widget) source);
-        }
-    }
-
     /**
      * Hook up a <code>Widget.Destroy</code> handler.
      * 
      * @since 4.0.20
      */
     public void connect(Widget.Destroy handler) {
-        GtkObject.connect(this, new DestroyAdapter(handler), false);
+        GtkWidget.connect(this, handler, false);
+    }
+
+    /**
+     * Signal fired when a Widget is given its size allocation.
+     * 
+     * @author Andrew Cowie
+     * @since 4.1.1
+     */
+    public interface SizeAllocate extends GtkWidget.SizeAllocateSignal
+    {
+        void onSizeAllocate(Widget source, Rectangle allocation);
+    }
+
+    /**
+     * Hook up a <code>Widget.SizeAllocate</code> handler.
+     * 
+     * @since 4.1.1
+     */
+    public void connect(Widget.SizeAllocate handler) {
+        GtkWidget.connect(this, handler, false);
+    }
+
+    /**
+     * Does the Widget prefer that it be given height for a given width, or
+     * vice versa?
+     * 
+     * <p>
+     * Part of GTK 3's height-for-width geometry management system.
+     * 
+     * @return
+     */
+    public SizeRequestMode getRequestMode() {
+        return GtkWidget.getRequestMode(this);
+    }
+
+    /**
+     * Will this Widget be given any additional space that it's parent
+     * Container has? The default is <code>false</code> which means that as a
+     * child this Widget will be allocated its natural size reqeust, but not
+     * more.
+     * 
+     * <p>
+     * This is the <var>hexpand</var> property.
+     * 
+     * @since 4.1.1
+     */
+    public void setExpandHorizontal(boolean setting) {
+        GtkWidget.setHexpand(this, setting);
+    }
+
+    /**
+     * <p>
+     * This is the <var>vexpand</var> property.
+     * 
+     * @since 4.1.1
+     */
+    public void setExpandVertical(boolean setting) {
+        GtkWidget.setVexpand(this, setting);
+    }
+
+    /**
+     * Set the horizontal positioning of a Widget in its parent Container.
+     * 
+     * <p>
+     * This is the <var>halign</var> property.
+     * 
+     * <p>
+     * <i>This is part of how the GTK 2.x Alignment Widget has been
+     * replaced.</i>
+     * 
+     * @since 4.1.1
+     */
+    public void setAlignHorizontal(Align align) {
+        GtkWidget.setHalign(this, align);
+    }
+
+    /**
+     * Set the vertical positioning of a Widget in its parent Container.
+     * 
+     * <p>
+     * This is the <var>valign</var> property.
+     * 
+     * @since 4.1.1
+     */
+    public void setAlignVertical(Align align) {
+        GtkWidget.setValign(this, align);
     }
 }
