@@ -1,20 +1,27 @@
 /*
- * TypeGenerator.java
+ * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright (c) 2007 Operational Dynamics Consulting Pty Ltd
- * Copyright (c) 2007 Vreixo Formoso
- * 
- * The code in this file, and the library it is a part of, are made available
- * to you by the authors under the terms of the "GNU General Public Licence,
- * version 2" See the LICENCE file for the terms governing usage and
- * redistribution.
+ * Copyright © 2007-2011 Operational Dynamics Consulting, Pty Ltd
+ * Copyright © 2007      Vreixo Formoso
+ *
+ * The code in this file, and the program it is a part of, is made available
+ * to you by its authors as open source software: you can redistribute it
+ * and/or modify it under the terms of the GNU General Public License version
+ * 2 ("GPL") as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.
+ *
+ * You should have received a copy of the GPL along with this program. If not,
+ * see http://www.gnu.org/licenses/. The authors of this program may be
+ * contacted through http://java-gnome.sourceforge.net/.
  */
 package com.operationaldynamics.codegen;
 
 import java.io.PrintWriter;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 
 import com.operationaldynamics.driver.DefsFile;
@@ -44,20 +51,20 @@ abstract class TypeGenerator extends Generator
     }
 
     public void writePublicCode(final PrintWriter out) {
-        commonFileHeader(out, objectType.javaType + ".java", true);
+        commonFileHeader(out, objectType.javaType + ".java");
         publicPackageAndImports(out);
         publicClassJavadocComment(out);
         publicClassDeclaration(out);
     }
 
     public void writeTranslationCode(final PrintWriter out) {
-        commonFileHeader(out, objectType.bindingsClass + ".java", false);
+        commonFileHeader(out, objectType.bindingsClass + ".java");
         packageStatementAndImports(out);
         translationClassDeclaration(out);
     }
 
     public void writeJniCode(final PrintWriter out) {
-        commonFileHeader(out, objectType.bindingsClass + ".c", false);
+        commonFileHeader(out, objectType.bindingsClass + ".c");
         hashIncludeStatements(out);
     }
 
@@ -76,26 +83,44 @@ abstract class TypeGenerator extends Generator
      * of single line strings with \n at the end of each. Oh well, it's done
      * now, and this was really the only long block of text.
      */
-    protected static void commonFileHeader(PrintWriter out, String fileName, boolean stub) {
+    protected static void commonFileHeader(PrintWriter out, String fileName) {
         out.print("/*\n");
-        out.print(" * ");
-        out.print(fileName);
-        out.print("\n *\n");
-        out.print(" * Copyright (c) 2006-2007 Operational Dynamics Consulting Pty Ltd, and Others\n");
+        out.print(" * java-gnome, a UI library for writing GTK and GNOME programs from Java!\n");
         out.print(" *\n");
-        out.print(" * The code in this file, and the library it is a part of, are made available\n");
-        out.print(" * to you by the authors under the terms of the \"GNU General Public Licence,\n");
-        out.print(" * version 2\" plus the \"Classpath Exception\" (you may link to this code as a\n");
-        out.print(" * library into other programs provided you don't make a derivation of it).\n");
-        out.print(" * See the LICENCE file for the terms governing usage and redistribution.\n");
-
-        if (stub) {
-            out.print(" */\n");
-            return;
-        }
-
+        out.print(" * Copyright © 2006-2011 Operational Dynamics Consulting, Pty Ltd and Others\n");
         out.print(" *\n");
-        out.print(" *                      THIS FILE IS GENERATED CODE!\n");
+        out.print(" * The code in this file, and the program it is a part of, is made available\n");
+        out.print(" * to you by its authors as open source software: you can redistribute it\n");
+        out.print(" * and/or modify it under the terms of the GNU General Public License version\n");
+        out.print(" * 2 (\"GPL\") as published by the Free Software Foundation.\n");
+        out.print(" *\n");
+        out.print(" * This program is distributed in the hope that it will be useful, but WITHOUT\n");
+        out.print(" * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or\n");
+        out.print(" * FITNESS FOR A PARTICULAR PURPOSE. See the GPL for more details.\n");
+        out.print(" *\n");
+        out.print(" * You should have received a copy of the GPL along with this program. If not,\n");
+        out.print(" * see http://www.gnu.org/licenses/. The authors of this program may be\n");
+        out.print(" * contacted through http://java-gnome.sourceforge.net/.\n");
+        out.print(" *\n");
+        out.print(" * Linking this library statically or dynamically with other modules is making\n");
+        out.print(" * a combined work based on this library. Thus, the terms and conditions of\n");
+        out.print(" * the GPL cover the whole combination. As a special exception (the\n");
+        out.print(" * \"Claspath Exception\"), the copyright holders of this library give you\n");
+        out.print(" * permission to link this library with independent modules to produce an\n");
+        out.print(" * executable, regardless of the license terms of these independent modules,\n");
+        out.print(" * and to copy and distribute the resulting executable under terms of your\n");
+        out.print(" * choice, provided that you also meet, for each linked independent module,\n");
+        out.print(" * the terms and conditions of the license of that module. An independent\n");
+        out.print(" * module is a module which is not derived from or based on this library. If\n");
+        out.print(" * you modify this library, you may extend the Classpath Exception to your\n");
+        out.print(" * version of the library, but you are not obligated to do so. If you do not\n");
+        out.print(" * wish to do so, delete this exception statement from your version.\n");
+        out.print(" */\n");
+    }
+
+    protected void generatedFileWarning(final PrintWriter out) {
+        out.print("/*\n");
+        out.print(" * THIS FILE IS GENERATED CODE!\n");
         out.print(" *\n");
         out.print(" * To modify its contents or behaviour, either update the generation program,\n");
         out.print(" * change the information in the source defs file, or implement an override for\n");
@@ -104,30 +129,25 @@ abstract class TypeGenerator extends Generator
     }
 
     protected void packageStatementAndImports(final PrintWriter out) {
-        final List types;
-        Iterator iter;
+        final List<String> types;
 
         out.print("package ");
         out.print(objectType.bindingsPackage);
         out.print(";\n\n");
+        generatedFileWarning(out);
+        out.print("\n");
 
-        types = new ArrayList();
+        types = new ArrayList<String>();
         types.add(objectType.bindingsPackage + ".Plumbing");
 
-        iter = data.getTypesToImport().iterator();
-        while (iter.hasNext()) {
-            Thing type = (Thing) iter.next();
-
+        for (Thing type : data.getTypesToImport()) {
             types.add(type.fullyQualifiedJavaClassName());
         }
 
         /* sort the types */
         Collections.sort(types);
 
-        iter = types.iterator();
-        while (iter.hasNext()) {
-            String t = (String) iter.next();
-
+        for (String t : types) {
             out.print("import ");
 
             out.print(t);
@@ -149,11 +169,16 @@ abstract class TypeGenerator extends Generator
 
     protected void hashIncludeStatements(final PrintWriter out) {
         out.print("\n");
+        generatedFileWarning(out);
+        out.print("\n");
+
         out.print("#include <jni.h>\n");
         out.print("#include <gtk/gtk.h>\n");
 
-        if (objectType.importHeader != null) {
-            out.print("#include <" + objectType.importHeader + ">\n");
+        if (objectType.importHeaders != null) {
+            for (String header : objectType.importHeaders) {
+                out.print("#include <" + header + ">\n");
+            }
         }
 
         out.print("#include \"bindings_java.h\"\n");
