@@ -1,7 +1,7 @@
 /*
  * java-gnome, a UI library for writing GTK and GNOME programs from Java!
  *
- * Copyright © 2007-2010 Operational Dynamics Consulting, Pty Ltd and Others
+ * Copyright © 2007-2011 Operational Dynamics Consulting, Pty Ltd and Others
  *
  * The code in this file, and the program it is a part of, is made available
  * to you by its authors as open source software: you can redistribute it
@@ -61,7 +61,6 @@ import org.gnome.gtk.ValidateStockItems;
 import org.gnome.gtk.ValidateTextBuffer;
 import org.gnome.gtk.ValidateTextViewBorderWindows;
 import org.gnome.gtk.ValidateTextViewProperties;
-import org.gnome.gtk.ValidateTextViewSpelling;
 import org.gnome.gtk.ValidateTreeModel;
 import org.gnome.gtk.ValidateTreeModelFilter;
 import org.gnome.gtk.ValidateTreeStore;
@@ -182,7 +181,6 @@ public class UnitTests
         suite.addTestSuite(ValidateInputMethods.class);
         suite.addTestSuite(ValidateTextViewProperties.class);
         suite.addTestSuite(ValidateTextViewBorderWindows.class);
-        suite.addTestSuite(ValidateTextViewSpelling.class);
         suite.addTestSuite(ValidateArrow.class);
         suite.addTestSuite(ValidatePangoTextRendering.class);
         suite.addTestSuite(ValidatePangoAttributeUsage.class);
